<?xml version="1.0" encoding="iso-8859-1"?>

<!-- INVOICE : formatage des donnees XML vers un affichage HTML
 
 Bertrand Le Quellec (c) 2013-2021
 
 Version: 1.7, Cree: 2013-10-30

  Modifie: 2021-10-03
  Modifie: 2013-10-30
  Modifie: 2014-06-20 - mise a jour titre du type de document
  Modifie: 2014-09-25 - ajout feuille de style de base
  Modifie: 2014-10-21 - suppression feuille de style de base par des valeurs globales
  Modifie: 2014-12-02 - mise a jour affichage liste produits/services et affichage adresse
  Modifie: 2015-09-10 - prise en compte de l'affichage du Logo
  Modifie: 2016-01-16 - reorganisation de l'affichage du total HT et correction Bug sur remise TTC
  Modifie: 2016-03-17 - ajout taxe sur Livraison et alternance de couleur des lignes Produit
 
 Description:
 Fichier Xsl de formatage d'un fichier Xml generique de donnees d'un objet unique Xml
 representant la structure d'une Facture (Invoice = Bill).
 -->

<xsl:stylesheet id="stylesheet" version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <!-- Declarations des variables designant les parametres de la Page. -->
  <xsl:variable name="margin"              select="'2px'" />
  <xsl:variable name="padding"             select="'5px'" />
  <xsl:variable name="background_color"    select="'#F4FAFC'" />
  <xsl:variable name="font_size"           select="'75%'" />
  <xsl:variable name="font_family"         select="'Verdana, Geneva, Tahoma, sans-serif'" />

  <!-- Declarations des variables designant les couleurs. -->
  <xsl:variable name="legendtop_color"     select="'Lavender'" />
  <xsl:variable name="legendleft_color"    select="'#B8CCEE'" />
  <xsl:variable name="rowseparator_color"  select="'Black'" />
  <xsl:variable name="content_color"       select="'#B8CCDC'" />
  <xsl:variable name="comment_color"       select="'#ffebcd'" />
  <xsl:variable name="actionleft_color"    select="'lightgrey'" />

  <!-- Declarations des variables designant le formatage des principaux tableaux. -->
  <xsl:variable name="table_color"         select="'#ffffff'" />
  <xsl:variable name="table_border"        select="'0'" />
  <xsl:variable name="table_spacing"       select="'1'" />
  <xsl:variable name="table_padding"       select="'0'" />
  <xsl:variable name="table_font"          select="'normal serif'" />

  <!-- Declarations des variables designant le formatage des tableaux secondaires. -->
  <xsl:variable name="table2_color"         select="'#ffffff'" />
  <xsl:variable name="table2_border"        select="'0'" />
  <xsl:variable name="table2_spacing"       select="'1'" />
  <xsl:variable name="table2_padding"       select="'0'" />

  <!-- La methode de formatage du resultat html -->
  <xsl:output
   method="html"
   encoding="ISO-8859-1"
   doctype-public="-//W3C//DTD HTML 4.01//EN"
   doctype-system="http://www.w3.org/TR/html4/strict.dtd"
   indent="yes" />

  <!-- Corps du resultat HTML : point de depart -->
  <xsl:template match="/">
    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="fr">

      <head>
        <title>
          <xsl:value-of disable-output-escaping="yes" select="Invoice/Title" />
          <xsl:value-of disable-output-escaping="yes" select="Invoice/Document_id" />
        </title>
        <meta name="description" content="Contact Manager - Facturation" />

        <meta name="publisher" content="BLQ software" />
        <meta name="author" content="BLQ software" />
        <meta name="copyright" content="BLQ software" />

        <meta name="http.language" content="French" />
        <meta name="Language" content="FR,BE,CH" />
        <meta http-equiv="Content-Language" content="fr,be,ch" />
      </head>

      <body style="margin:{$margin}; padding:{$padding}; background-color:{$background_color}; font-size:{$font_size}; font-family:{$font_family}; " >
        <!-- *********************************************
            Traitement de la racine Xml nommee Invoice 
           ********************************************* -->
        <xsl:apply-templates select="Invoice" />
      </body>
    </html>
  </xsl:template>

  <!-- 
   ===========================================
   INVOICE : premier niveau de traitement Xml 
   =========================================== -->
  <xsl:template match="Invoice">

    <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
      <tr>
        <!-- LOGO -->
        <th bgcolor="white" valign="center">
          <xsl:choose>
            <xsl:when test="Logo">
              <img src="{Logo}" />
            </xsl:when>
            <xsl:otherwise>
              <!-- Insertion d'un espace si aucune valeur -->
              <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </th>

        <!-- TYPE FACTURATION -->
        <th width="40%" align="left">
          <font style="text-transform: capitalize; font-size:x-large;">
            <b>
              <xsl:choose>
                <xsl:when test="@type= 'Quote'">
                  <xsl:text>devis</xsl:text>
                </xsl:when>
                <xsl:when test="@type= 'Invoice'">
                  <xsl:text>facture</xsl:text>
                </xsl:when>
                <xsl:when test="@type= 'Order'">
                  <xsl:text>commande</xsl:text>
                </xsl:when>
                <xsl:when test="@type= 'Receipt'">
                  <xsl:text>reeu</xsl:text>
                </xsl:when>
                <xsl:when test="@type= 'Delivry'">
                  <xsl:text>livraison</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <!-- Insertion d'un espace si aucune valeur -->
                  <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </b>
          </font>
        </th>

        <!-- DATE DE CREATION -->
        <th align="right">
          <font size="-2">
            <i>
              cree le <xsl:value-of select="@created" />
            </i>
          </font>
        </th>

        <!-- DATE DE MODIFICATION -->
        <th align="right">
          <font size="-2">
            <i>
              modifie le <xsl:value-of select="@changed" />
            </i>
          </font>
        </th>
      </tr>

      <tr>
        <!-- COLONNE VIDE -->
        <th>
          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
        </th>

        <!-- TITRE -->
        <th align="left">
          <xsl:choose>
            <xsl:when test="Title">
              <xsl:value-of select="Title" />
            </xsl:when>
            <xsl:otherwise>
              <!-- Insertion d'un espace si aucune valeur -->
              <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </th>

        <!-- IDENTIFIANT DOCUMENT -->
        <th align="right">
          <xsl:choose>
            <xsl:when test="Document_id">
              <xsl:value-of select="Document_id" />
            </xsl:when>
            <xsl:otherwise>
              <!-- Insertion d'un espace si aucune valeur -->
              <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </th>

        <!-- AUTRE REFERENCE -->
        <th align="right">
          <xsl:choose>
            <xsl:when test="Reference">
              <xsl:value-of select="Reference" />
            </xsl:when>
            <xsl:otherwise>
              <!-- Insertion d'un espace si aucune valeur -->
              <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </th>
      </tr>
    </table>

    <!-- ADRESSES ======================================================================== -->
    <xsl:if test="count(Addresses) > 0">
      <br />
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
        <tr>
          <th valign="top">
            <!-- Le tableau des adresses contiendra des donnees -->
            <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
              <tr>
                <!-- == SHIPPER ================================================================= -->
                <!-- Boucle sur la liste des valeurs Shipper Xml -->
                <th valign="top">
                  <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">
                    <tr>
                      <th colspan="1" align="center" bgcolor="{$legendleft_color}">
                        <font style="text-transform:uppercase; font-weight:bold; ">expediteur</font>
                      </th>
                    </tr>

                    <xsl:if test="Addresses/Shipper">
                      <!-- Boucle sur la liste des donnees du contenu Shipper -->
                      <xsl:for-each select="Addresses/Shipper/Item">
                        <tr>
                          <th align="left">
                            <code>
                              <!-- xsl:value-of select="Item" -->
                              <xsl:value-of select="substring-after(., ']|[')" />
                            </code>
                          </th>
                        </tr >
                      </xsl:for-each>
                    </xsl:if>
                  </table>
                </th>

                <!-- == RECIPIENT ================================================================= -->
                <!-- Boucle sur la liste des valeurs Recipent Xml -->
                <th valign="top">
                  <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">
                    <tr>
                      <th align="center" bgcolor="{$legendleft_color}">
                        <font style="text-transform:uppercase; font-weight:bold; ">destinataire</font>
                      </th>
                    </tr>

                    <xsl:if test="Addresses/Recipient">
                      <!-- Boucle sur la liste des donnees du contenu Recipient -->
                      <xsl:for-each select="Addresses/Recipient/Item">
                        <tr>
                          <th align="left" >
                            <code>
                              <!-- xsl:value-of select="Item" -->
                              <xsl:value-of select="substring-after(., ']|[')" />
                            </code>
                          </th>
                        </tr >
                      </xsl:for-each>
                    </xsl:if>
                  </table>
                </th>

                <!-- == DELIVRY =================================================================== -->
                <!-- Boucle sur la liste des valeurs Delivry Xml -->
                <th valign="top">
                  <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">
                    <tr>
                      <th align="center" bgcolor="{$legendleft_color}">
                        <font style="text-transform:uppercase; font-weight:bold; ">livraison</font>
                      </th>
                    </tr>

                    <xsl:if test="Addresses/Delivry">
                      <!-- Boucle sur la liste des donnees du contenu Delivry -->
                      <xsl:for-each select="Addresses/Delivry/Item">
                        <tr>
                          <th align="left" >
                            <code>
                              <!-- xsl:value-of select="Item" -->
                              <xsl:value-of select="substring-after(., ']|[')" />
                            </code>
                          </th>
                        </tr >
                      </xsl:for-each>
                    </xsl:if>
                  </table>
                </th>
              </tr>

              <!-- Fermeture du tableau Html des Adresses-->
            </table >
          </th>
        </tr>
      </table>
    </xsl:if>

    <!-- PRODUITS ======================================================================== -->
    <xsl:if test="count(Grid) > 0">
      <br />
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">

        <!-- == ENTETE ========================================================== -->
        <xsl:if test="count(Grid/Headers)>0">
          <tr>
            <xsl:for-each select="Grid/Headers/GridCol">
              <th align="center" bgcolor="{$legendleft_color}">
                <b>
                  <xsl:value-of select="." />
                </b>
              </th>
            </xsl:for-each>
          </tr>
        </xsl:if>

        <!-- == CONTENU ========================================================== -->
        <xsl:if test="count(Grid/GridRows)>0">
          <!-- Boucle sur la liste des Lignes Produit du fichier Xml -->
          <xsl:for-each select="Grid/GridRows">
            <xsl:apply-templates select="GridRow" />
          </xsl:for-each>
          <!-- Fermeture du tableau Html des Produits -->
        </xsl:if>

        <!-- == TOTAL ============================================================ -->
        <tr >
          <th>
            <!-- Insertion d'un espace -->
            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          </th>
          <th>
            <!-- Insertion d'un espace -->
            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          </th>
          <th>
            <!-- Insertion d'un espace -->
            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          </th>

          <xsl:if test="Quantity">
            <th valign="middle" align="center" bgcolor="{$comment_color}">
              <code>
                <xsl:value-of select="Quantity" />
              </code>
            </th>
          </xsl:if>

          <th>
            <!-- Insertion d'un espace -->
            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          </th>

          <xsl:if test="Discount">
            <th valign="middle" align="right" bgcolor="{$comment_color}">
              <code>
                <xsl:value-of select="Discount" />
              </code>
            </th>
          </xsl:if>

          <xsl:if test="VAT">
            <th valign="middle" align="right" bgcolor="{$comment_color}">
              <code>
                <xsl:value-of select="VAT" />
              </code>
            </th>
          </xsl:if>

          <xsl:if test="Amount">
            <th valign="middle" align="right" bgcolor="{$comment_color}">
              <code>
                <xsl:value-of select="Amount" />
              </code>
            </th>
          </xsl:if>
        </tr>

      </table>
    </xsl:if>

    <!-- NOTES, TAXES & REMISES ========================================================== -->
    <p align="right">
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">

        <!-- SEPARATEUR ========================================================================== -->
        <tr>
          <th bgcolor="{$rowseparator_color}" colspan="2"></th>
        </tr>

        <tr >
          <th align="left" valign="top">
            <!-- NOTES =========================================================================== -->
            <xsl:choose>
              <xsl:when test="Notes">
                <pre>
                  <xsl:value-of select="Notes" />
                </pre>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </th>

          <th valign="top" width="50%">
            <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">

              <!-- TOTAL HT -->
              <xsl:if test="Amount">
                <tr>
                  <th align="right" bgcolor="{$content_color}">
                    <font size="-1">
                      <xsl:value-of select="Amount/@Label" />
                    </font>
                  </th>
                  <th align="right">
                    <code>
                      <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    </code>
                  </th>
                  <th align="right" bgcolor="{$content_color}">
                    <code>
                      <xsl:value-of select="Amount/Amount" />
                    </code>
                  </th>
                </tr>

                <!-- SEPARATEUR ========================================================================== -->
                <tr>
                  <th bgcolor="{$rowseparator_color}" colspan="3"></th>
                </tr>
              </xsl:if>

              <!-- DISCOUNT : Affichage des eventuels Discounts globaux sur HT -->
              <xsl:if test="count(GlobalDiscount)>0">
                <xsl:if test="GlobalDiscount/DiscountLessVAT">
                  <tr>
                    <th align="right" bgcolor="{$legendleft_color}">
                      <font size="-1">
                        <xsl:value-of select="GlobalDiscount/DiscountLessVAT/@Label" />
                      </font>
                    </th>
                    <th align="right">
                      <code>
                        <xsl:choose>
                          <xsl:when test="GlobalDiscount/DiscountLessVAT/@status= 'True'">
                            <xsl:value-of select="GlobalDiscount/DiscountLessVAT/Percent" /> %
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                          </xsl:otherwise>
                        </xsl:choose>
                      </code>
                    </th>
                    <th align="right" bgcolor="{$comment_color}">
                      <code>
                        <xsl:value-of select="GlobalDiscount/DiscountLessVAT/Amount" />
                      </code>
                    </th>
                  </tr>

                  <!-- SEPARATEUR ========================================================================== -->
                  <tr>
                    <th bgcolor="{$rowseparator_color}" colspan="3"></th>
                  </tr>
                </xsl:if>
              </xsl:if>

              <!-- TAXE : Affichage des Taxes Specifiques -->
              <xsl:if test="count(OtherTax)>0">
                <xsl:if test="OtherTax/OtherTax1">
                  <tr>
                    <xsl:apply-templates select="OtherTax/OtherTax1" />
                  </tr>
                </xsl:if>
                <xsl:if test="OtherTax/OtherTax2">
                  <tr>
                    <xsl:apply-templates select="OtherTax/OtherTax2" />
                  </tr>
                </xsl:if>
                <xsl:if test="OtherTax/OtherTax3">
                  <tr>
                    <xsl:apply-templates select="OtherTax/OtherTax3" />
                  </tr>
                </xsl:if>

                <!-- SEPARATEUR ========================================================================== -->
                <tr>
                  <th bgcolor="{$rowseparator_color}" colspan="3"></th>
                </tr>
              </xsl:if>

              <!-- DISCOUNT : Affichage des eventuels Discounts globaux sur TTC -->
              <xsl:if test="count(GlobalDiscount)>0">
                <xsl:if test="GlobalDiscount/DiscountPlusVAT">
                  <tr>
                    <th align="right" bgcolor="{$legendleft_color}">
                      <font size="-1">
                        <xsl:value-of select="GlobalDiscount/DiscountPlusVAT/@Label" />
                      </font>
                    </th>
                    <th align="right">
                      <code>
                        <xsl:choose>
                          <xsl:when test="GlobalDiscount/DiscountPlusVAT/@status= 'True'">
                            <xsl:value-of select="GlobalDiscount/DiscountPlusVAT/Percent" /> %
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                          </xsl:otherwise>
                        </xsl:choose>
                      </code>
                    </th>
                    <th align="right" bgcolor="{$comment_color}">
                      <code>
                        <xsl:value-of select="GlobalDiscount/DiscountPlusVAT/Amount" />
                      </code>
                    </th>
                  </tr>

                  <!-- SEPARATEUR ========================================================================== -->
                  <tr>
                    <th bgcolor="{$rowseparator_color}" colspan="3"></th>
                  </tr>
                </xsl:if>
              </xsl:if>

              <!-- ASSURANCE & FRAIS DE LIVRAISON SUR TTC -->
              <xsl:if test="Insurrance">
                <tr>
                  <th align="right" bgcolor="{$legendleft_color}">
                    <font size="-1">
                      <xsl:value-of select="Insurrance/@Label" />
                    </font>
                  </th>
                  <th align="right">
                    <code>
                      <xsl:choose>
                        <xsl:when test="Insurrance/@status= 'True'">
                          <xsl:value-of select="Insurrance/Percent" /> %
                        </xsl:when>
                        <xsl:otherwise>
                          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                        </xsl:otherwise>
                      </xsl:choose>
                    </code>
                  </th>
                  <th align="right" bgcolor="{$comment_color}">
                    <code>
                      <xsl:value-of select="Insurrance/Amount" />
                    </code>
                  </th>
                </tr>
              </xsl:if>

              <xsl:if test="Delivry">
                <tr>
                  <th align="right" bgcolor="{$legendleft_color}">
                    <font size="-1">
                      <xsl:value-of select="Delivry/@Label" />
                    </font>
                  </th>
                  <th align="right">
                    <code>
                      <xsl:choose>
                        <xsl:when test="Delivry/@status= 'True'">
                          <xsl:value-of select="Delivry/Percent" /> %
                        </xsl:when>
                        <xsl:otherwise>
                          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                        </xsl:otherwise>
                      </xsl:choose>
                    </code>
                  </th>
                  <th align="right" bgcolor="{$comment_color}">
                    <code>
                      <xsl:value-of select="Delivry/Amount" />
                    </code>
                  </th>
                </tr>

                <!-- TAXE LIVRAISON -->
                <xsl:if test="DelivryTax">
                  <tr>
                    <th align="right" bgcolor="{$legendleft_color}">
                      <font size="-1">
                        <xsl:value-of select="DelivryTax/@Label" />
                      </font>
                    </th>
                    <th align="right">
                      <code>
                        <xsl:choose>
                          <xsl:when test="DelivryTax/@status= 'True'">
                            <xsl:value-of select="DelivryTax/Percent" /> %
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                          </xsl:otherwise>
                        </xsl:choose>
                      </code>
                    </th>
                    <th align="right" bgcolor="{$comment_color}">
                      <code>
                        <xsl:value-of select="DelivryTax/Amount" />
                      </code>
                    </th>
                  </tr>
                </xsl:if>
                
                <!-- SEPARATEUR ========================================================================== -->
                <tr>
                  <th bgcolor="{$rowseparator_color}" colspan="3"></th>
                </tr>
              </xsl:if>
             
              <!-- FRAIS SERVICE -->
              <xsl:if test="Service">
                <tr>
                  <th align="right" bgcolor="{$legendleft_color}">
                    <font size="-1">
                      <xsl:value-of select="Service/@Label" />
                    </font>
                  </th>
                  <th align="right">
                    <code>
                      <xsl:choose>
                        <xsl:when test="Service/@status= 'True'">
                          <xsl:value-of select="Service/Percent" /> %
                        </xsl:when>
                        <xsl:otherwise>
                          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                        </xsl:otherwise>
                      </xsl:choose>
                    </code>
                  </th>
                  <th align="right" bgcolor="{$comment_color}">
                    <code>
                      - <xsl:value-of select="Service/Amount" />
                    </code>
                  </th>
                </tr>
              </xsl:if>

              <!-- ARRHES DEJA PAYE -->
              <xsl:if test="Deposit">
                <tr>
                  <th align="right" bgcolor="{$legendleft_color}">
                    <font size="-1">
                      <xsl:value-of select="Deposit/@Label" />
                    </font>
                  </th>
                  <th align="right">
                    <code>
                      <xsl:choose>
                        <xsl:when test="Deposit/@status= 'True'">
                          <xsl:value-of select="Deposit/Percent" /> %
                        </xsl:when>
                        <xsl:otherwise>
                          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                        </xsl:otherwise>
                      </xsl:choose>
                    </code>
                  </th>
                  <th align="right" bgcolor="{$comment_color}">
                    <code>
                      - <xsl:value-of select="Deposit/Amount" />
                    </code>
                  </th>
                </tr>
              </xsl:if>

              <!-- TOTAL TTC A PAYER -->
              <xsl:if test="TotalAmount">
                <tr>
                  <th bgcolor="{$rowseparator_color}" colspan="3"></th>
                </tr>
                <tr>
                  <th align="right" bgcolor="{$content_color}">
                    <font size="-1">
                      <xsl:value-of select="TotalAmount/@Label" />
                    </font>
                  </th>
                  <th align="right">
                    <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                  </th>
                  <th align="right" bgcolor="{$content_color}">
                    <code>
                      <xsl:value-of select="TotalAmount/Amount" />
                    </code>
                  </th>
                </tr>
              </xsl:if>
            </table>
          </th>
        </tr>

        <!-- SEPARATEUR ========================================================================== -->
        <tr>
          <th bgcolor="{$rowseparator_color}" colspan="3"></th>
        </tr>
      </table>
    </p>

    <!-- PERSONNALISATION ================================================================ -->
    <xsl:if test="count(Customs/Custom) > 0">
      <!-- table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="70%" align="left">
        <tr -->
      <!-- PERSONNALISATION ===================================================================== -->
      <!-- Recupere le nombre de sous Nodes, car seules les informations non vides sont e traiter -->
      <!-- th valign="top"-->
      <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">
        <!-- Boucle sur la liste des Customs du fichier Xml -->
        <xsl:for-each select="Customs">
          <xsl:apply-templates select="Custom" />
        </xsl:for-each>
        <!-- Fermeture du tableau Html des Customs -->
      </table>
      <!-- /th -->
      <!-- /tr>
      </table -->
    </xsl:if>

  </xsl:template>

  <!-- TAXES SPECIFIQUES ================================================================= -->
  <xsl:template match="OtherTax1">
    <xsl:if test="@status= 'True'">
      <th align="right" bgcolor="{$legendleft_color}">
        <font size="-1">
          <xsl:value-of select="@Label" />
        </font>
      </th>
      <th align="right">
        <code>
          <xsl:value-of select="Percent" /> %
        </code>
      </th>
      <th align="right" bgcolor="{$comment_color}">
        <code>
          <xsl:value-of select="Amount" />
        </code>
      </th>
    </xsl:if>
  </xsl:template>

  <xsl:template match="OtherTax2">
    <xsl:if test="@status= 'True'">
      <th align="right" bgcolor="{$legendleft_color}">
        <font size="-1">
          <xsl:value-of select="@Label" />
        </font>
      </th>
      <th align="right">
        <code>
          <xsl:value-of select="Percent" /> %
        </code>
      </th>
      <th align="right" bgcolor="{$comment_color}">
        <code>
          <xsl:value-of select="Amount" />
        </code>
      </th>
    </xsl:if>
  </xsl:template>

  <xsl:template match="OtherTax3">
    <xsl:if test="@status= 'True'">
      <th align="right" bgcolor="{$legendleft_color}">
        <font size="-1">
          <xsl:value-of select="@Label" />
        </font>
      </th>
      <th align="right">
        <code>
          <xsl:value-of select="Percent" /> %
        </code>
      </th>
      <th align="right" bgcolor="{$comment_color}">
        <code>
          <xsl:value-of select="Amount" />
        </code>
      </th>
    </xsl:if>
  </xsl:template>

  <!-- LIGNE PRODUIT/SERVICE ============================================================ -->
  <xsl:template match="GridRow">
    <tr>
      <!-- Alternance des couleurs de fond de chaque ligne  -->
      <xsl:if test="position() mod 2 = 0">
        <xsl:attribute name="bgcolor">lightgrey</xsl:attribute>
        <!-- 
        En cas de passage d'une couleur incluse dans une variable globale : $actionleft_color
        la couleur visualisee est differente ! Donc la couleur est directement ecrite
        A explorer plus tard... -->
      </xsl:if>
      
      <xsl:for-each select="GridCol">
        <th align="center">
          <code>
            <xsl:value-of select="." />
            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          </code>
        </th>
      </xsl:for-each>
    </tr>
  </xsl:template>

  <!-- CHAMPS PERSONNALISES ============================================================= -->
  <xsl:template match="Custom">
    <xsl:if test = "normalize-space(Data)">
      <tr>
        <!-- LABEL -->
        <th bgcolor="{$content_color}" align="right" style="width:30%;">
          <xsl:value-of select="Label"/>
          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
        </th>

        <!-- DATA -->
        <th align="left">
          <xsl:value-of select="Data" />
          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
        </th>
      </tr>
    </xsl:if>
  </xsl:template>

</xsl:stylesheet>
